aboutsummaryrefslogtreecommitdiffstats
path: root/swarm/storage/localstore/retrieval_index_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'swarm/storage/localstore/retrieval_index_test.go')
-rw-r--r--swarm/storage/localstore/retrieval_index_test.go10
1 files changed, 5 insertions, 5 deletions
diff --git a/swarm/storage/localstore/retrieval_index_test.go b/swarm/storage/localstore/retrieval_index_test.go
index 9f5b452c5..bccdc6ed9 100644
--- a/swarm/storage/localstore/retrieval_index_test.go
+++ b/swarm/storage/localstore/retrieval_index_test.go
@@ -20,7 +20,7 @@ import (
"strconv"
"testing"
- "github.com/ethereum/go-ethereum/swarm/storage"
+ "github.com/dexon-foundation/dexon/swarm/storage"
)
// BenchmarkRetrievalIndexes uploads a number of chunks in order to measure
@@ -32,10 +32,10 @@ import (
// Measurements on MacBook Pro (Retina, 15-inch, Mid 2014) show
// that two separated indexes perform better.
//
// # go test -benchmem -run=none github.com/ethereum/go-ethereum/swarm/storage/localstore -bench BenchmarkRetrievalIndexes -v
// goos: darwin
// goarch: amd64
-// pkg: github.com/ethereum/go-ethereum/swarm/storage/localstore
+// pkg: github.com/dexon-foundation/dexon/swarm/storage/localstore
// BenchmarkRetrievalIndexes/1000-8 20 75556686 ns/op 19033493 B/op 84500 allocs/op
// BenchmarkRetrievalIndexes/10000-8 1 1079084922 ns/op 382792064 B/op 1429644 allocs/op
// BenchmarkRetrievalIndexes/100000-8 1 16891305737 ns/op 2629165304 B/op 12465019 allocs/op
@@ -104,10 +104,10 @@ func benchmarkRetrievalIndexes(b *testing.B, o *Options, count int) {
//
// Measurements on MacBook Pro (Retina, 15-inch, Mid 2014).
//
// go test -benchmem -run=none github.com/ethereum/go-ethereum/swarm/storage/localstore -bench BenchmarkUpload -v
// goos: darwin
// goarch: amd64
-// pkg: github.com/ethereum/go-ethereum/swarm/storage/localstore
+// pkg: github.com/dexon-foundation/dexon/swarm/storage/localstore
// BenchmarkUpload/1000-8 20 59437463 ns/op 25205193 B/op 23208 allocs/op
// BenchmarkUpload/10000-8 2 580646362 ns/op 216532932 B/op 248090 allocs/op
// BenchmarkUpload/100000-8 1 22373390892 ns/op 2323055312 B/op 3995903 allocs/op
@@ -32,10 +32,10 @@ import (
// that two separated indexes perform better.
//
-// # go test -benchmem -run=none github.com/ethereum/go-ethereum/swarm/storage/localstore -bench BenchmarkRetrievalIndexes -v
+// # go test -benchmem -run=none github.com/dexon-foundation/dexon/swarm/storage/localstore -bench BenchmarkRetrievalIndexes -v
// goos: darwin
// goarch: amd64
@@ -104,10 +104,10 @@ func benchmarkRetrievalIndexes(b *testing.B, o *Options, count int) {
// Measurements on MacBook Pro (Retina, 15-inch, Mid 2014).
//
-// go test -benchmem -run=none github.com/ethereum/go-ethereum/swarm/storage/localstore -bench BenchmarkUpload -v
+// go test -benchmem -run=none github.com/dexon-foundation/dexon/swarm/storage/localstore -bench BenchmarkUpload -v
// goos: darwin
// goarch: amd64